pub struct DragCancelEvent {
pub start_state: PointerState,
pub current_state: PointerState,
pub button: Option<PointerButton>,
pub pointer: PointerInfo,
pub custom_data: Option<Rc<dyn Any>>,
}Expand description
Event data for when a drag operation is cancelled.
Only sent to the element being dragged via DragSourceEvent::Cancel.
Occurs when the drag is aborted (e.g., Escape key pressed, pointer left window,
or pointer released without a valid drop target accepting the drop).
Fields
start_state: PointerStateThe pointer state from when the drag started
current_state: PointerStateFinal pointer state
Which button initiated the drag
pointer: PointerInfoPointer identity
custom_data: Option<Rc<dyn Any>>Custom data passed from the drag source