pub struct DragEndEvent {
pub other_element: Option<ElementId>,
pub start_state: PointerState,
pub current_state: PointerState,
pub button: Option<PointerButton>,
pub pointer: PointerInfo,
pub custom_data: Option<Rc<dyn Any>>,
}Expand description
Event data for when a drag operation completes with a drop.
This struct is shared between:
- [
DragSourceEvent::Drop] - sent to the element being dragged DragTargetEvent::Drop- sent to the drop target (which can callprevent_default()to accept)
Fields
other_element: Option<ElementId>The “other” element involved in this drop event.
When sent to the dragged element (via [DragSourceEvent::Drop]):
This is the drop target element where the drop occurred, or None if dropped
outside any valid drop target.
When sent to a drop target (via DragTargetEvent::Drop):
This is always Some containing the dragged element that was dropped.
start_state: PointerStateThe pointer state from when the drag started
current_state: PointerStateFinal pointer state
Which button initiated the drag and has now been released
pointer: PointerInfoPointer identity
custom_data: Option<Rc<dyn Any>>Custom data passed from the drag source