pub struct EventCx<'a> {
pub window_state: &'a mut WindowState,
pub event: Event,
pub world_transform: Affine,
pub triggered_by: Option<&'a Event>,
pub hit_path: Option<Rc<[ElementId]>>,
pub phase: Phase,
pub target: ElementId,
pub source: ElementId,
pub dispatch: Option<Rc<[Dispatch]>>,
pub source_id: ElementId,
/* private fields */
}Fields
window_state: &'a mut WindowStateevent: EventAn event transformed to the local coordinate space of the target node.
world_transform: AffineThe transform from window space to the local space of the target element.
triggered_by: Option<&'a Event>The event that caused this synthetic event, if any. Not transformed.
hit_path: Option<Rc<[ElementId]>>All visual IDs under the pointer for pointer events.
phase: PhaseThe event phase for this local event.
target: ElementIdThe target of this event.
source: ElementIdThe visual ID that is the source/origin of this event.
dispatch: Option<Rc<[Dispatch]>>The full dispatch sequence for this event.
source_id: ElementIdThe element that caused the event to be dispatched.
Implementations
Sourceimpl<'a> EventCx<'a>
impl<'a> EventCx<'a>
Sourcepub fn stop_immediate_propagation(&mut self)
pub fn stop_immediate_propagation(&mut self)
Stop propagation to other listeners on this target AND to other nodes in the path.
Sourcepub fn prevent_default(&mut self)
pub fn prevent_default(&mut self)
Prevent any default actions for this event.
Sourcepub fn is_default_prevented(&self) -> bool
pub fn is_default_prevented(&self) -> bool
Check if preventDefault() was called on this event.
Sourcepub fn request_pointer_capture(&mut self, pointer_id: PointerId) -> bool
pub fn request_pointer_capture(&mut self, pointer_id: PointerId) -> bool
Request pointer capture for this element.
Sourcepub fn start_drag(
&mut self,
drag_token: DragToken,
config: DragConfig,
use_default_preview: bool,
) -> bool
pub fn start_drag( &mut self, drag_token: DragToken, config: DragConfig, use_default_preview: bool, ) -> bool
Request that this element start tracking a drag.
Should be called in response to PointerCaptureEvent::Gained.